@@ -232,13 +232,14 @@ fill_widgets (GnomePilotDDialog *gpdd)
 }
 
 gboolean
-gnome_pilot_ddialog_run_and_close (GnomePilotDDialog *gpdd)
+gnome_pilot_ddialog_run_and_close (GnomePilotDDialog *gpdd, GtkWindow *parent)
 {
 	GnomePilotDDialogPrivate *priv;
 	gint btn;
 	
 	priv = gpdd->priv;
 	
+	gnome_dialog_set_parent (GNOME_DIALOG (priv->dialog), parent);
 	btn = gnome_dialog_run (GNOME_DIALOG (priv->dialog));
 	
 	if (btn == 0)
