@@ -31,7 +31,7 @@ void fill_speed_menu (GtkOptionMenu *optionMenu, guint default_speed);
 void fill_synctype_menu (GtkOptionMenu *optionMenu, GnomePilotConduitSyncType type);
 void fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state);
 void fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state);
-void show_popup_menu (GtkCList *list, GdkEventButton *event, GtkMenu *menu);
+gboolean show_popup_menu (GtkTreeView *treeview, GdkEventButton *event, GtkMenu *menu);
 
 /* Filtering callbacks */
 void insert_numeric_callback (GtkEditable *editable, const gchar *text,
@@ -42,7 +42,6 @@ void insert_device_callback (GtkEditable *editable, const gchar *text,
 			     gint len, gint *position, void *data);
 
 gboolean check_editable (GtkEditable *editable);
-gboolean check_selection (GtkCList *clist);
 
 /* General routines */
 GPilotPilot *get_default_pilot (PilotState *state);
@@ -57,7 +56,7 @@ const gchar* display_sync_type_name (gboolean enabled, GnomePilotConduitSyncType
 
 gboolean check_pilot_info (GPilotPilot* pilot1, GPilotPilot *pilot2);
 gboolean check_device_info (GPilotDevice* device1, GPilotDevice *device2);
-gboolean check_base_directory (gchar *dir_name);
+gboolean check_base_directory (const gchar *dir_name);
 
 /* Dialogs */
 void error_dialog (gchar *mesg, ...);
@@ -67,7 +66,7 @@ GPilotDevice *choose_pilot_dialog (PilotState *state);
 /* Configuration routines */
 void read_device_config (GtkObject *object, GPilotDevice* device);
 void read_pilot_config (GtkObject *object, GPilotPilot *pilot);
-void read_host_config (GtkObject *object, PilotState *state);
+void read_host_config (GObject *object, PilotState *state);
 
 void save_config_and_restart (GnomePilotClient *gpc, PilotState *state);
 
